aboutsummaryrefslogtreecommitdiffstats
path: root/src/MusicChunk.hxx
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/MusicChunk.hxx14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/MusicChunk.hxx b/src/MusicChunk.hxx
index dddcfa269..835221233 100644
--- a/src/MusicChunk.hxx
+++ b/src/MusicChunk.hxx
@@ -39,15 +39,15 @@ struct Tag;
* A chunk of music data. Its format is defined by the
* MusicPipe::Push() caller.
*/
-struct music_chunk {
+struct MusicChunk {
/** the next chunk in a linked list */
- struct music_chunk *next;
+ MusicChunk *next;
/**
* An optional chunk which should be mixed into this chunk.
* This is used for cross-fading.
*/
- struct music_chunk *other;
+ MusicChunk *other;
/**
* The current mix ratio for cross-fading: 1.0 means play 100%
@@ -92,13 +92,13 @@ struct music_chunk {
AudioFormat audio_format;
#endif
- music_chunk()
+ MusicChunk()
:other(nullptr),
length(0),
tag(nullptr),
replay_gain_serial(0) {}
- ~music_chunk();
+ ~MusicChunk();
bool IsEmpty() const {
return length == 0 && tag == nullptr;
@@ -118,7 +118,7 @@ struct music_chunk {
* where you may write into. After you are finished, call
* Expand().
*
* @param chunk the music_chunk object
* @param audio_format the audio format for the appended data;
* must stay the same for the life cycle of this chunk
* @param data_time the time within the song
@@ -134,7 +134,7 @@ struct music_chunk {
* Increases the length of the chunk after the caller has written to
* the buffer returned by Write().
*
* @param chunk the music_chunk object
* @param audio_format the audio format for the appended data; must
* stay the same for the life cycle of this chunk
* @param length the number of bytes which were appended
@@ -118,7 +118,7 @@ struct music_chunk {
* Expand().
*
- * @param chunk the music_chunk object
+ * @param chunk the MusicChunk object
* @param audio_format the audio format for the appended data;
* must stay the same for the life cycle of this chunk
@@ -134,7 +134,7 @@ struct music_chunk {
* the buffer returned by Write().
*
- * @param chunk the music_chunk object
+ * @param chunk the MusicChunk object
* @param audio_format the audio format for the appended data; must
* stay the same for the life cycle of this chunk